summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/enumliteral.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit22253cd8fbc0bd2e70f32aaf1f95ea3a3e819a60 (patch)
treebabc4a761925023e16fa94633959f35d1c251887 /umbrello/umbrello/enumliteral.h
parent0813b39aed2cf4c84157a22c4c9594336d93d412 (diff)
downloadtdesdk-22253cd8fbc0bd2e70f32aaf1f95ea3a3e819a60.tar.gz
tdesdk-22253cd8fbc0bd2e70f32aaf1f95ea3a3e819a60.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdesdk@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'umbrello/umbrello/enumliteral.h')
-rw-r--r--umbrello/umbrello/enumliteral.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/umbrello/umbrello/enumliteral.h b/umbrello/umbrello/enumliteral.h
index 3e530c4d..e9a63b1a 100644
--- a/umbrello/umbrello/enumliteral.h
+++ b/umbrello/umbrello/enumliteral.h
@@ -29,19 +29,19 @@ public:
/**
* Sets up an enum literal.
*
* @param tqparent The tqparent of this UMLEnumLiteral.
* @param name The name of this UMLEnumLiteral.
* @param id The unique id given to this UMLEnumLiteral.
*/
- UMLEnumLiteral(const UMLObject* tqparent,
+ UMLEnumLiteral(const UMLObject* parent,
const TQString& name, Uml::IDType id = Uml::id_None);
/**
* Sets up an enum literal.
*
* @param tqparent The tqparent of this UMLEnumLiteral.
*/
- UMLEnumLiteral(const UMLObject* tqparent);
+ UMLEnumLiteral(const UMLObject* parent);
/**
* Overloaded '==' operator
@@ -72,7 +72,7 @@ public:
/**
* Display the properties configuration dialog for the enum literal.
*/
- bool showPropertiesDialog(TQWidget* tqparent);
+ bool showPropertiesDialog(TQWidget* parent);
protected:
/**
@@ -29,19 +29,19 @@ public:
* Sets up an enum literal.
*
- * @param tqparent The tqparent of this UMLEnumLiteral.
+ * @param parent The parent of this UMLEnumLiteral.
* @param name The name of this UMLEnumLiteral.
* @param id The unique id given to this UMLEnumLiteral.
@@ -29,19 +29,19 @@ public:
* Sets up an enum literal.
*
- * @param tqparent The tqparent of this UMLEnumLiteral.
+ * @param parent The parent of this UMLEnumLiteral.
*/